Module error_handler
bevy_
render
0.19.0
Module error_
handler
Module Items
Structs
Enums
In crate bevy_
render
bevy_render
Module
error_
handler
Structs

Render
Error
An error encountered during rendering. These are errors reported by wgpu validation layers, and typically indicate problems in the way it is being used.
Render
Error
Handler
Determines what
RenderErrorPolicy
should be used to respond to a given
RenderError
.
Enums

Error
Type
A classification of WebGPU error for implementers of the WebGPU API to use in their own error layer(s).
Render
Error
Policy
Resource to indicate renderer behavior upon error.