Struct bevy_render::Render
source · pub struct Render;Expand description
The main render schedule.
Implementations
sourceimpl Render
impl Render
sourcepub fn base_schedule() -> Schedule
pub fn base_schedule() -> Schedule
Sets up the base structure of the rendering Schedule.
The sets defined in this enum are configured to run in order,
and a copy of apply_deferred is inserted into each *Flush set.