Trait bevy_render::render_phase::Draw
source · pub trait Draw<P: PhaseItem>: Send + Sync + 'static {
fn draw<'w>(
&mut self,
world: &'w World,
pass: &mut TrackedRenderPass<'w>,
view: Entity,
item: &P
);
}Expand description
A draw function which is used to draw a specific PhaseItem.
They are the general form of drawing items, whereas RenderCommands
are more modular.
Required Methods
sourcefn draw<'w>(
&mut self,
world: &'w World,
pass: &mut TrackedRenderPass<'w>,
view: Entity,
item: &P
)
fn draw<'w>(
&mut self,
world: &'w World,
pass: &mut TrackedRenderPass<'w>,
view: Entity,
item: &P
)
Draws the PhaseItem by issuing draw calls via the TrackedRenderPass.